"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const lexer_1 = require("../lexer");
const rule_1 = require("../rule");
class NoUtf8Bom extends rule_1.Rule {
    documentation() {
        return {
            description: `This file is saved with the UTF-8 byte order mark (BOM) present. It is neither required or recommended to use.\n\nInstead the document should be served with the \`Content-Type: application/javascript; charset=utf-8\` header.`,
            url: rule_1.ruleDocumentationUrl(__filename),
        };
    }
    setup() {
        const unregister = this.on("token", (event) => {
            if (event.type === lexer_1.TokenType.UNICODE_BOM) {
                this.report(null, "File should be saved without UTF-8 BOM", event.location);
            }
            /* since the BOM must be the very first thing the rule can now be disabled for the rest of the run */
            this.setEnabled(false);
            unregister();
        });
    }
}
exports.default = NoUtf8Bom;
